s|<img src="http://jupyter.org/assets/nav_logo.svg"/>|<img src="www/jupyter/nav_logo.svg"/>|
s|<img src="https://jupyter.org/assets/nav_logo.svg"/>|<img src="www/jupyter/nav_logo.svg"/>|
s|<img src="https://www.python.org/static/img/python-logo-large.png"/>|<img src="www/python/python-logo-large.png"/>|
s|<img src="https://www.python.org/static/favicon.ico"/>|<img src="www/python/favicon.ico"/>|
s|<img src="http://python.org/images/python-logo.gif"/>|<img src="www/python/python-logo.gif"/>|
s|src="https://www.youtube.com/embed/WAikxUGbomY"|src="about:blank" srcdoc="The video https://www.youtube.com/embed/WAikxUGbomY should be displayed, but it got removed because of https://lintian.debian.org/tags/privacy-breach-generic.html ."|
