s|<img alt="Jupyter logo (remote)" src="http://jupyter.org/assets/nav_logo.svg" />|<img alt="Jupyter logo (remote)" src="www/assets/jupyter/nav_logo.svg" />|
s|<img alt="Jupyter logo" src="https://jupyter.org/assets/main-logo.svg" />|<img alt="Jupyter logo" src="www/assets/main-logo.svg" />|
s|<img alt="Python logo (remote)" src="https://www.python.org/static/img/python-logo-large.png" />|<img alt="Python logo (remote)" src="www/python/python-logo-large.png" />|
s|<audio src="https://upload.wikimedia.org/wikipedia/commons/6/61/DescenteInfinie.ogg" controls>|<audio src="www/wikimediacommons/DescenteInfinie.ogg" controls>|
s|<video src="https://upload.wikimedia.org/wikipedia/commons/4/42/Shepard_Calais_1906_FrenchGP.ogv" controls autoplay loop>|<video src="www/wikimediacommons/Shepard_Calais_1906_FrenchGP.ogv" controls autoplay loop>|
