s|src="https://anaconda.org/conda-forge/nbsphinx/badges/version.svg"|src="www/anaconda/version.svg"|
s|src="https://repology.org/badge/vertical-allrepos/python:nbsphinx.svg"|src="www/repology/nbsphinx.svg"|
s|src="https://badge.fury.io/py/nbsphinx.svg"|src="www/fury/nbsphinx.svg"|
s|src="https://badge.fury.io/py/nbsphinx.png"|src="www/fury/nbsphinx.png"|
